==> simulab-0.0.2.tar.gz: simulab-0.0.2/README.md <==
# SimuLab

Simple simulation framework, created during a course of the Discrete Events Simulation Laboratory, from the University of Buenos Aires (https://modsimu.exp.dc.uba.ar/sed/)

[![PyPI](https://img.shields.io/pypi/v/simulab?color=blue&label=PyPI%20Version&logo=python&logoColor=white)](https://pypi.org/project/simulab/)
[![GitHub release (latest by date)](https://img.shields.io/github/v/release/EzequielPuerta/simulab?label=Latest%20Release&display_name=tag&logo=github&logoColor=white)](https://github.com/EzequielPuerta/simulab/releases/latest)
![GitHub License](https://img.shields.io/github/license/EzequielPuerta/simulab?label=License&logo=github&logoColor=white)
[![Package Status](https://img.shields.io/pypi/status/simulab.svg?label=PyPI%20Status&logo=python&logoColor=white)](https://pypi.org/project/simulab/)
[![CircleCI](https://img.shields.io/circleci/build/gh/EzequielPuerta/simulab/main?label=CircleCI%20Build&logo=circleci&logoColor=white)](https://circleci.com/gh/EzequielPuerta/simulab)
[![CodeFactor Grade](https://img.shields.io/codefactor/grade/github/EzequielPuerta/simulab/main?label=CodeFactor&logo=codefactor&logoColor=white)](https://www.codefactor.io/repository/github/ezequielpuerta/simulab)
[![Codecov](https://img.shields.io/codecov/c/gh/EzequielPuerta/simulab?label=Codecov&logo=codecov&logoColor=white)](https://codecov.io/gh/EzequielPuerta/simulab)

> [!WARNING]
> #### This framework is a WIP

## Jupyter Notebooks

On ***[this](https://github.com/EzequielPuerta-University/modelado_y_simulacion_de_sistemas_complejos)*** repository you can find some Jupyter Notebooks that use this framework. It's a set of models seen on some optional subject of my university career at the University of Buenos Aires.

## Framework explained

* Models included
    * [Abstract](docs/abstract.md)
    * [Computationals](docs/computational.md)
        * [Schelling's Segregation](docs/computational.md#schellings-segregation)
        * [Real State Market](docs/computational.md#real-state-market)
        * [Condensation](docs/computational.md#condensation)
        * [Conway's Game of Life](docs/computational.md#conways-game-of-life)
* [Simulation](docs/simulation.md)

==> simulab-0.0.14.tar.gz: simulab-0.0.14/README.md <==
# SimuLab

Simple simulation framework, created during a course of the Discrete Events Simulation Laboratory, from the University of Buenos Aires (https://modsimu.exp.dc.uba.ar/sed/)

[![PyPI](https://img.shields.io/pypi/v/simulab?color=blue&label=PyPI%20Version&logo=python&logoColor=white)](https://pypi.org/project/simulab/)
[![GitHub release (latest by date)](https://img.shields.io/github/v/release/EzequielPuerta/simulab?label=Latest%20Release&display_name=tag&logo=github&logoColor=white)](https://github.com/EzequielPuerta/simulab/releases/latest)
![GitHub License](https://img.shields.io/github/license/EzequielPuerta/simulab?label=License&logo=github&logoColor=white)
[![Package Status](https://img.shields.io/pypi/status/simulab.svg?label=PyPI%20Status&logo=python&logoColor=white)](https://pypi.org/project/simulab/)
[![CircleCI](https://img.shields.io/circleci/build/gh/EzequielPuerta/simulab/main?label=CircleCI%20Build&logo=circleci&logoColor=white)](https://circleci.com/gh/EzequielPuerta/simulab)
[![CodeFactor Grade](https://img.shields.io/codefactor/grade/github/EzequielPuerta/simulab/main?label=CodeFactor&logo=codefactor&logoColor=white)](https://www.codefactor.io/repository/github/ezequielpuerta/simulab)
[![Codecov](https://img.shields.io/codecov/c/gh/EzequielPuerta/simulab?label=Codecov&logo=codecov&logoColor=white)](https://codecov.io/gh/EzequielPuerta/simulab)

> [!WARNING]
> #### This framework is a WIP

## Jupyter Notebooks

On ***[this](https://github.com/EzequielPuerta-University/modelado_y_simulacion_de_sistemas_complejos)*** repository you can find some Jupyter Notebooks (in Spanish) that use this framework. It's a set of models seen on some optional subject of my university career at the University of Buenos Aires.

## Framework explained

* Models included
    * [Abstract](docs/abstract.md)
    * [Computationals](docs/computational.md)
        * [Schelling's Segregation](docs/computational.md#schellings-segregation)
        * [Real State Market](docs/computational.md#real-state-market)
        * [Condensation](docs/computational.md#condensation)
        * [Conway's Game of Life](docs/computational.md#conways-game-of-life)
* [Simulation](docs/simulation.md)
